.icon-controlpanel-RichMenuSettings:before,
.icon-navigation_menu_properties:before {
  content: '\e838';
}
#portal-globalnavWrapper {
    position:relative;
}
#portal-globalnav {
  position: relative;
  width: 100%;
  float:left;
}

#portal-globalnav .menuContent a {
  display:inline;
  padding:auto;
  background:transparent;
  border:none;
  min-width:auto;
  padding:inherit;
}

#portal-globalnav #content {
  font-size:100%;
  clear:none;
  margin:0;
}

#portal-globalnav #manage_sections {
  left: 0;
  position: absolute;
  top: 0;
  z-index:3000;
}

#portal-globalnav ul.smenu {
  padding-left: 0;
  list-style-type: none;
  min-width: 200px;
  background-color: #DDD;
}

#portal-globalnav ul.smenu li.sectionItem {
  border-bottom: 1px solid #dddada;
  width: 100%;

}

#portal-globalnav ul.smenu li.sectionItem a.sectionText {
  padding: 1em;
  display: block;
  border:none;
}
#portal-globalnav li.sectionItem a.sectionText {
  display:block;
}
#portal-globalnav ul.smenu li.sectionItem a.sectionText:focus,
#portal-globalnav ul.smenu li.sectionItem a.sectionText:hover,
#portal-globalnav ul.smenu li.sectionItem a.sectionText:hover .image {
  color: white;
  background-color: #205C90;
  text-decoration: none;
}

#portal-globalnav ul.smenu li.sectionItem.menuhover > a.sectionText,
#portal-globalnav ul.smenu li.sectionItem.menuhover > a.sectionText .image {
  color: white;
  background-color: #205C90;
  text-decoration: none;
}

#portal-globalnav ul.smenu.useflexbox {
  align-items: stretch;
}

#portal-globalnav ul.smenu.useflexbox li.sectionItem > a.sectionText {
  box-sizing:border-box;
  height: 100%;
}

#portal-globalnav ul.smenu.useflexbox li.sectionItem > a.sectionText.hasChildren {
  height: auto;
}

#portal-globalnav ul.smenu.columns_2 {
  min-width: 250px;
}

#portal-globalnav ul.smenu.columns_2 > li {
  width: 50%;
  float: left;
  -webkit-box-flex: 0 1 48%;
  -moz-box-flex: 0 1 48%;
  -webkit-flex: 0 1 48%;
  -ms-flex: 0 1 48%;
  flex: 0 1 48%;
}

#portal-globalnav ul.smenu.columns_3 {
  min-width: 300px;
}

#portal-globalnav ul.smenu.columns_3 > li {
  width: 33.3%;
  float: left;
  -webkit-box-flex: 0 1 31%;
  -moz-box-flex: 0 1 31%;
  -webkit-flex: 0 1 31%;
  -ms-flex: 0 1 31%;
  flex: 0 1 31%;
}

#portal-globalnav ul.smenu.columns_4 {
  min-width: 400px;
}

#portal-globalnav ul.smenu.columns_4 > li {
  width: 25%;
  float: left;
  -webkit-box-flex: 0 1 23%;
  -moz-box-flex: 0 1 23%;
  -webkit-flex: 0 1 23%;
  -ms-flex: 0 1 23%;
  flex: 0 1 23%;
}

#portal-globalnav li.sectionItem {
  position: relative;
  display:block;
}

#portal-globalnav > li.sectionItem {
  float:left;
}

#portal-globalnav li.sectionItem.right > .sectionTreeLevel1 {
  right: initial;
  left: unset;
}

#portal-globalnav li.sectionItem.left > .sectionTreeLevel1 {
  right: unset;
  left: initial;
}

#portal-globalnav li.sectionItem.center > .sectionTreeLevel1 {
  right: auto;
  left: 50%;
}

#portal-globalnav li.sectionItem.right_site,
#portal-globalnav li.sectionItem.left_site {
  position: static !important;
}

#portal-globalnav li.sectionItem.left_site > .sectionTreeLevel1 {
  left: 0;
}

#portal-globalnav li.sectionItem.right_site > .sectionTreeLevel1 {
  right: 0;
}

#portal-globalnav li.sectionItem.menuhover > a.sectionText {
  background-color: #205C90;
  color:white;
}

#portal-globalnav li.sectionItem.menuhover > ul.smenu,
#portal-globalnav li.sectionItem.menuhover > ul.sectionSubmenu,
#portal-globalnav li.sectionItem.menuhover > .menuPage > ul.smenu {
  display: block;
}

#portal-globalnav li.sectionItem > ul.smenu.useflexbox,
#portal-globalnav li.sectionItem > ul.sectionSubmenu.useflexbox,
#portal-globalnav li.sectionItem > .menuPage > ul.smenu.useflexbox {
  justify-content: space-between;
  -webkit-flex-wrap: wrap;
  -moz-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}
#portal-globalnav li.sectionItem.menuhover > ul.smenu.useflexbox,
#portal-globalnav li.sectionItem.menuhover > ul.sectionSubmenu.useflexbox,
#portal-globalnav li.sectionItem.menuhover > .menuPage > ul.smenu.useflexbox {
  display: -webkit-box;
  /* OLD - iOS 6-, Safari 3.1-6 */
  display: -moz-box;
  /* OLD - Firefox 19- (buggy but mostly works) */
  display: -ms-flexbox;
  /* TWEENER - IE 10 */
  display: -webkit-flex;
  /* NEW - Chrome */
  display: flex;
}

#portal-globalnav.hover li.sectionItem > .sectionTree,
#portal-globalnav.click li.sectionItem > .sectionTree {
  display: none;
  position: absolute;
}

#portal-globalnav.hover li.sectionItem > .sectionTree.always,
#portal-globalnav.click li.sectionItem > .sectionTree.always {
  position: relative;
}

#portal-globalnav.hover li.sectionItem:hover > .sectionTree,
#portal-globalnav.hover li.sectionItem.menuhover > .sectionTree,
#portal-globalnav.click li.sectionItem.menuhover > .sectionTree {
  display: block;
  z-index: 100;
}

#portal-globalnav.hover li.sectionItem:hover > .sectionTree.useflexbox,
#portal-globalnav.hover li.sectionItem.menuhover > .sectionTree.useflexbox,
#portal-globalnav.click li.sectionItem.menuhover > .sectionTree.useflexbox {
  display: flex;
  justify-content: space-between;
}

#portal-globalnav .sectionTreeLevel1 .sectionTreeLevel2.always {
  border-left: none;
  display: block !important;
  left: 0 !important;
  top: 0 !important;
  position: relative;
  margin-bottom: 1.5em;
  padding-left: 1.5em;
}

#portal-globalnav .sectionTreeLevel1 .sectionTreeLevel2.always li.sectionItem.liLevel2 a.sectionText {
  padding: 0.5em;
}

#portal-globalnav .sectionTreeLevel1 ul.smenu {
  position: abolute;
  top: 0;
  left: 100%;
  border-left: 1px solid #dddada;
}

#portal-globalnav .menuPage {
  width: 400px;
  float: none;
  padding: 1.5em;
  background: #f2f1f1;
  font-size: 90%;
  zoom: 1;
}

#portal-globalnav .menuPage.sectionTreeLevel1 ul.smenu {
  position: relative;
  left: 0px;
  top: 0px;
}

#portal-globalnav .menuPage .sectionTree.left,
#portal-globalnav .menuPage .sectionTreeLevel1.left {
  float: left;
  margin-right:1.5em;
}

#portal-globalnav .menuPage .sectionTree.right,
#portal-globalnav .menuPage .sectionTreeLevel1.right {
  float: right;
  margin-left:1.5em;
}

#portal-globalnav .menuPage #viewlet-above-content-title,
#portal-globalnav .menuPage #viewlet-below-content-title,
#portal-globalnav .menuPage #viewlet-below-content-body,
#portal-globalnav .menuPage .documentActions,
#portal-globalnav .menuPage .reviewHistory {
  display: none;
}

#portal-globalnav .menuPage.sectionTreeLevel1 {
  display: block;
}

#portal-globalnav .menuPage.sectionTreeLevel1 a.sectionText {
  border-bottom: none;
}

#portal-globalnav .menuPage.sectionTreeLevel1 ul.smenu {
  border-left: none;
}

#portal-globalnav .menuPage.hasSubMenu {
  width: 500px;
}

#portal-globalnav .menuContent {
  overflow: auto;
  float: none;
  color: #4d4d4d;
}

#portal-globalnav .hasSubMenu .menuContent {
  width: auto;
}

#portal-globalnav .hasSubMenu .menuContent.right {
  margin-right: 200px;
}

#portal-globalnav .hasSubMenu .menuContent.left {
  margin-left: 200px;
  clear: none;
}

#portal-globalnav .menuDescription .title {
  display: block;
  border-bottom: 1px solid #dddada;
  font-weight: bold;
  margin-bottom: 0.3em;
}

#portal-globalnav .menuImage .title,
#portal-globalnav a.always {
  display: block;
  border-bottom: 1px solid #dddada;
  font-weight: bold;
  margin-bottom: 0.3em;
}

#portal-globalnav a.menuImage {
  overflow: auto;
}

#portal-globalnav a.menuImage .image {
  display: block;
  background-color: #f2f1f1;
  float: left;
  padding-right: 1em;
}
#mobile_menu {
  display:none;
}
@media (max-width: 768px) {
  #portal-globalnav .menuPage {
    width: auto;
  }
  #portal-globalnav .menuPage .sectionTree.right,
  #portal-globalnav .menuPage .sectionTreeLevel1.right {
    float: left;
  }
  #portal-globalnav .menuContent.right {
    margin-right: 0;
  }
  #portal-globalnav .hasSubMenu .menuContent.left {
    margin-left: 0;
  }
  #portal-globalnav ul.smenu.columns_2,
  #portal-globalnav ul.smenu.columns_3,
  #portal-globalnav ul.smenu.columns_4 {
    min-width:0;
  }
  #portal-globalnav ul.smenu.columns_2 li.sectionItem.liLevel1,
  #portal-globalnav ul.smenu.columns_3 li.sectionItem.liLevel1,
  #portal-globalnav ul.smenu.columns_4 li.sectionItem.liLevel1 {
    width: auto;
    float: none;
    -webkit-box-flex: initial;
    -moz-box-flex: initial;
    -webkit-flex: initial;
    -ms-flex: initial;
    flex: initial;
  }
  #portal-globalnav li.sectionItem.menuhover > ul.smenu.useflexbox,
  #portal-globalnav li.sectionItem.menuhover > .menuPage > ul.smenu.useflexbox {
    display: block !important;
    width: 100% !important;
  }
  #portal-globalnav .sectionTreeLevel1 {
    width: 100% !important;
  }
  #portal-globalnav .sectionTree {
    width: auto !important;
  }
  #portal-globalnav span.image_tile .image,
  #portal-globalnav span.image_tile .description {
    display: none !important;
  }
  #portal-globalnav span.image_tile .title {
    margin-left: 0;
  }
  #portal-globalnav ul.smenu.sectionTreeLevel2.always li.sectionItem {
    padding-left: 0px;
  }
  #portal-globalnav.hover li.sectionItem .sectionTree,
  #portal-globalnav.click li.sectionItem .sectionTree {
    position: relative;
  }
  #portal-globalnav .sectionTreeLevel1 ul.smenu {
    left: 0;
  }
  #portal-globalnav.hover li.sectionItem:hover > .sectionTree,
  #portal-globalnav.hover li.sectionItem:hover > .sectionTree.useflexbox {
    display: none;
  }
  #portal-globalnav.hover li.sectionItem.menuhover > .sectionTree,
  #portal-globalnav.click li.sectionItem.menuhover > .sectionTree {
    display: block;
    position: relative;
  }
  #portal-globalnav .hasSubMenu .menuContent {
    margin: 0 !important;
    clear: both;
    width: 100%;
  }
  #mobile_menu {
    font-size:30px;
    padding:5px;
    border:1px solid #007bb3;
    border-radius:5px;
    top:0;
    color:white;
    text-align:center;
    display:block;
    float:right;
    margin-right:5px;
    background-color:#007bb3;
  }
  #portal-globalnav {
    display:none;
    min-width:0 !important;
    position:absolute;
    top:100%;
    right:0;
    width:auto;
    margin-bottom:0;
    z-index:300;
  }
  #portal-globalnav li.sectionItem.liLevel0 {
    margin-right:0px;
    margin-left:0;
  }
  #portal-globalnav .sectionTree {
    position:relative !important;
    top: 0 !important;
    left:0 !important;
  }
  #portal-globalnav .liLevel0 {
    float:none;
    width:220px;
    background-color:#DDD;
    clear:both;
  }

  #portal-globalnavWrapper {
    background:#ddd none repeat scroll 0 0;
    float:left;
    width:100%;
    margin-bottom:1em;
  }
}
.plone-navbar-collapse.in {
  overflow-y: visible !important;
}
.icon-bar {
    display: block;
    width: 22px;
    height: 2px;
    border-radius: 1px;
    background: white;
    margin-top: 2px;
}
.icon-bar + .icon-bar {
    margin-top: 5px;
}
.icon-bar + .icon-bar + .icon-bar {
    margin-bottom: 3px;
}
